@@ -1,11 +1,10 @@
-import pandas as pd
-import openpyxl
-from chargebeecli.constants.constants import Export_Formats, Export_Formats_Extensions
-import click
-from pathlib import Path
 import os
+from pathlib import Path
 
-from chargebeecli.util.printer import custom_print, custom_print_error
+import pandas as pd
+
+from chargebeecli.constants.constants import Export_Formats, Export_Formats_Extensions, ERROR_HEADER, Formats
+from chargebeecli.printer.printer import custom_print
 
 _DEFAULT_OUTPUT_FILE_NAME = 'result'
 
@@ -32,7 +31,16 @@ class Exporter(object):
         self.df = pd.DataFrame(self.data, columns=self.headers)
 
     def to_be_exported(self):
-        raise NotImplementedError("Please Implement this method")
+        return self.export_format and self.export_path and self.file_name and \
+               self.response_format.lower() == Formats.TABLE.value
+
+    def export_data(self):
+        if self.response.status_code != 200:
+            self.headers = ERROR_HEADER
+        if self.to_be_exported():
+            Exporter(self.headers, self.tables).export(_path=self.export_path, _export_format=self.export_format,
+                                                       _file_name=self.file_name)
+        return self
 
     def export(self, _path, _export_format, _file_name=_DEFAULT_OUTPUT_FILE_NAME, compression=False):
         try:
@@ -43,12 +51,12 @@ class Exporter(object):
             elif Export_Formats.HTML.value.lower() == _export_format.lower():
                 self.export_html(path=_path, _file_name=_file_name)
             else:
-                click.echo('format not supported')
+                custom_print('format not supported', err=True)
                 exit()
 
             custom_print('!!!  exported !!')
         except Exception as e:
-            custom_print_error(e)
+            custom_print(e, err=True)
 
     def export_csv(self, path, _file_name, compression):
         self.df.to_csv(Path(os.path.join(path, _file_name + Export_Formats_Extensions.CSV.value)),
