@@ -1,29 +1,39 @@
-from abc import ABC
+import json
 
 from requests import Response
 
-from chargebeecli.Configuration import Configuration
-from chargebeecli.processor import Processor
-from chargebeecli.response_formatter import ResponseFormatter
-from chargebeecli.validator import Validator
-import json
+from chargebeecli.config.Configuration import Configuration
+from chargebeecli.constants.constants import Formats
+from chargebeecli.export.Exporter import Exporter
+from chargebeecli.formater.response_formatter import ResponseFormatter
+from chargebeecli.printer.printer import Printer
+from chargebeecli.processors.processor import Processor
+from chargebeecli.validator.validator import Validator
 
 
-class Profile(Processor, Validator, ResponseFormatter, ABC):
+class Profile(Processor, Validator, ResponseFormatter, Exporter, Printer):
 
-    def __init__(self):
-        self.response = None
+    def __init__(self, export_format, export_path, file_name, response_format, _operation, _input_columns):
         self.headers = self.get_api_header()
+        self.export_format = export_format
+        self.export_path = export_path
+        self.file_name = file_name
+        self.tables = None
+        self.response_format = response_format
+        self.operation = _operation
+        self.input_columns = _input_columns
 
-    def validate_param(self, __input_columns):
-        self.headers = super().validate_param(__input_columns, self.headers)
+    def validate_param(self):
+        self.headers = super().validate_param(self.input_columns, self.headers)
         return self
 
     def get_api_header(self):
         return ["name", "api_key", "account"]
 
-    def format(self, __format, __operation):
-        super().format(self.response, __format, __operation, self.headers, 'profile', 'list')
+    def format(self):
+        if self.to_be_formatted():
+            self.tables = super(Profile, self).format(self.response, self.response_format, self.operation,
+                                                      self.headers, 'profile', 'list')
         return self
 
     def process(self, ctx, operation, payload, resource_id):
@@ -74,3 +84,9 @@ class Profile(Processor, Validator, ResponseFormatter, ABC):
         response._content = json.dumps({'profile': {'name': resource_id, 'message': 'deleted'}}).encode('utf-8')
         Configuration.Instance().delete_section_or_profile(resource_id)
         return response
+
+    def table_to_be_printed(self):
+        return self.to_be_formatted()
+
+    def to_be_formatted(self):
+        return self.response_format.lower() == Formats.TABLE.value
